==> cuery-0.2-bin.zip: cuery-0.2/src/java/org/trix/cuery/value/AbstractCSSFrequency.java <==
/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.value;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: AbstractCSSFrequency.java,v 1.0 2005/08/09 20:29:38 Teletha Exp $
 */
public abstract class AbstractCSSFrequency extends AbstractCSSValue implements CSSFrequency {

    /**
     * Create AbstractCSSFrequency instance.
     * 
     * @param frequency A frequency.
     * @param previous A previous token.
     */
    public AbstractCSSFrequency(String frequency, CSSValue previous) {
        super(previous);

        this.stringValue = frequency;
        this.floatValue = Float.parseFloat(frequency);
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getFloatValue()
     */
    public float getFloatValue() {
        return floatValue;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getStringValue()
     */
    public String getStringValue() {
        return stringValue;
    }

    /**
     * @see org.trix.cuery.value.AbstractCSSValue#getCssText()
     */
    public String getCssText() {
        return stringValue + getDimensionUnitText();
    }

}

==> cuery-0.4-bin.zip: cuery-0.4/src/java/org/trix/cuery/value/AbstractCSSFrequency.java <==
/*
 * Copyright 2004-2005 The Trix Development Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trix.cuery.value;

/**
 * DOCUMENT.
 * 
 * @author <a href="mailto:Teletha.T@gmail.com">Teletha Testarossa</a>
 * @version $ Id: AbstractCSSFrequency.java,v 1.01 2005/09/14 22:16:38 Teletha Exp $
 */
public abstract class AbstractCSSFrequency extends AbstractCSSValue implements CSSFrequency {

    /**
     * Create AbstractCSSFrequency instance.
     * 
     * @param frequency A frequency.
     * @param previous A previous token.
     */
    public AbstractCSSFrequency(String frequency, CSSValue previous) {
        super(previous);

        // check unit
        String unit = getDimensionUnitText();

        if (frequency.endsWith(unit)) {
            frequency = frequency.substring(0, frequency.length() - unit.length());
        }

        this.stringValue = frequency;
        this.floatValue = Float.parseFloat(frequency);
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getFloatValue()
     */
    public float getFloatValue() {
        return floatValue;
    }

    /**
     * @see org.w3c.css.sac.LexicalUnit#getStringValue()
     */
    public String getStringValue() {
        return stringValue;
    }

    /**
     * @see org.trix.cuery.value.AbstractCSSValue#getCssText()
     */
    public String getCssText() {
        return stringValue + getDimensionUnitText();
    }

}
